@@ -1,6 +1,7 @@
 import os
 import re
 import logging
+import sys
 
 from mkdocs.plugins import BasePlugin
 from mkdocs.config import config_options
@@ -63,6 +64,11 @@ class PrintSitePlugin(BasePlugin):
             msg += "Please update the 'plugins:' section in your mkdocs.yml"
             logger.warning(msg)
 
+        if "--dirtyreload" in sys.argv:
+            msg = "[mkdocs-print-site] Note the 'print-site' page does render all pages "
+            msg += "when using the --dirtyreload option."
+            logger.warning(msg)
+
         # Get abs path to cover_page_template
         self.cover_page_template_path = ""
         if self.config.get("add_cover_page"):
